@@ -6,7 +6,7 @@ use Mojo::Util qw(dumper);
 use DBI;
 use Carp qw(croak);
 
-our $VERSION  = '0.19';
+our $VERSION  = '0.20';
 
 use MojoX::Mysql::DB;
 use MojoX::Mysql::Result;
@@ -159,7 +159,7 @@ sub _logging_sql {
 		$sql =~ s/\n+/ /g;
 		$sql =~ s/^\s//;
 		$sql =~ s/\s$//;
-		if(@_){
+		if(defined @_ && @_){
 			$self->{'app'}->log->debug("$sql --- ".join(" | ",@_)." ---");
 		}
 		else{
